package org.commonjava.tensor.discover;

import org.commonjava.maven.atlas.common.ref.ProjectRef;
import org.commonjava.maven.atlas.common.ref.ProjectVersionRef;
import org.commonjava.maven.atlas.common.version.SingleVersion;
import org.commonjava.maven.atlas.effective.workspace.GraphWorkspace;
import org.commonjava.maven.atlas.effective.workspace.GraphWorkspaceConfiguration;
import org.commonjava.maven.atlas.spi.GraphDriverException;
import org.commonjava.tensor.data.TensorDataException;
import org.commonjava.tensor.data.TensorDataManager;
import org.commonjava.util.logging.Logger;

public final class DiscoveryUtils
{

    private static final Logger logger = new Logger( DiscoveryUtils.class );

    private DiscoveryUtils()
    {
    }

    public static void selectSingle( final SingleVersion ver, final ProjectVersionRef ref,
                                     final TensorDataManager dataManager )
        throws TensorDataException
    {
        if ( !ver.isConcrete() )
        {
            logger.error( "Cannot select a non-concrete version: %s for: %s. Ignoring.", ver.renderStandard(), ref );
            return;
        }

        try
        {
            GraphWorkspace ws = dataManager.getCurrentWorkspace();
            if ( ws == null )
            {
                ws = dataManager.createTemporaryWorkspace( new GraphWorkspaceConfiguration() );
            }

            ws.selectVersion( ref, ver );
        }
        catch ( final GraphDriverException e )
        {
            throw new TensorDataException( "Failed to record selected version: %s for: %s. Reason: %s", e, ver, ref,
                                           e.getMessage() );
        }
    }

    public static void selectWildcard( final SingleVersion ver, final ProjectRef ref,
                                       final TensorDataManager dataManager )
        throws TensorDataException
    {
        if ( !ver.isConcrete() )
        {
            logger.error( "Cannot select a non-concrete version: %s for all: %s. Ignoring.", ver.renderStandard(), ref );
            return;
        }

        try
        {
            GraphWorkspace ws = dataManager.getCurrentWorkspace();
            if ( ws == null )
            {
                ws = dataManager.createTemporaryWorkspace( new GraphWorkspaceConfiguration() );
            }

            ws.selectVersionForAll( ref, ver );
        }
        catch ( final GraphDriverException e )
        {
            throw new TensorDataException( "Failed to record selected version: %s for all: %s. Reason: %s", e, ver,
                                           ref, e.getMessage() );
        }
    }

}
