package org.commonjava.tensor.inject;

import java.io.File;
import java.io.IOException;

import javax.annotation.PreDestroy;
import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.inject.Default;
import javax.enterprise.inject.Produces;
import javax.inject.Inject;

import org.commonjava.maven.atlas.effective.EGraphManager;
import org.commonjava.maven.atlas.spi.effective.EGraphDriver;
import org.commonjava.maven.atlas.spi.neo4j.effective.FileNeo4JEGraphDriver;
import org.commonjava.tensor.config.TensorConfig;

@ApplicationScoped
public class TensorCoreProvider
{

    @Inject
    private TensorConfig config;

    private EGraphDriver driver;

    private EGraphManager graphs;

    @Produces
    @Default
    public synchronized EGraphManager getGraphs()
    {
        if ( graphs == null )
        {
            graphs = new EGraphManager( getDriver() );
        }

        return graphs;
    }

    @Produces
    @TensorProduction
    @Default
    public synchronized EGraphDriver getDriver()
    {
        if ( driver == null )
        {
            final File dbDir = config.getDatabaseDir();
            dbDir.mkdirs();

            driver = new FileNeo4JEGraphDriver( dbDir );
        }

        return driver;
    }

    @PreDestroy
    public void shutdown()
        throws IOException
    {
        graphs.close();
    }

}
